@@ -1,8 +1,9 @@
 package Net::Kubernetes::Resource::ReplicationController;
 # ABSTRACT: Object representatioon of a Kubernetes Replication Controller
-$Net::Kubernetes::Resource::ReplicationController::VERSION = '0.16';
+$Net::Kubernetes::Resource::ReplicationController::VERSION = '0.17';
 use Moose;
 use URI;
+use Time::HiRes;
 
 
 extends 'Net::Kubernetes::Resource';
@@ -12,6 +13,22 @@ with 'Net::Kubernetes::Resource::Role::HasPods';
 
 
 
+sub scale {
+    my($self, $replicas, $timeout) = @_;
+    $timeout ||= 5;
+    $self->spec->{replicas} = $replicas;
+    $self->update;
+    my $st = time;
+    while((time - $st) < $timeout){
+        my $pods = $self->get_pods;
+        if(scalar(@$pods) == $replicas){
+            return "scaled";
+        }
+        sleep(0.3);
+    }
+    return 0;
+}
+
 return 42;
 
 __END__
@@ -26,7 +43,7 @@ Net::Kubernetes::Resource::ReplicationController - Object representatioon of a K
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 METHODS
 
