@@ -10,9 +10,13 @@ my $kube = Net::Kubernetes->new(url=>'http://172.18.8.101:8080');
 
 my $ns = $kube->get_namespace('default');
 
+my ($rc) = $ns->list_rc(labels=>{'name'=>'doppler-storage-pod-v1'});
+
+print $rc->scale(2)."\n";
+
+
 #my $sec = $ns->build_secret('testing', { 'sshpubkeypub' => '/home/dave/.ssh/id_rsa.pub', 'otherthingjson' => {type=>'JSON', value=>{text=>'Ha Ha'}} });
 
-print Dumper($kube->list_nodes)."\n";
 
 
 
